-- @ Ziuta
-- @ 25/01/2014
--
-- http://landwirtschafts-simulator.pl/
--
-- Copyright (C) Ziuta, All Rights Reserved.

rcw3000 = {};

function rcw3000.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Sprayer, specializations);
end;

function rcw3000:load(xmlFile)
	self.belt = {};
    local i = 0;
    while true do
		local key = string.format("vehicle.rcw3.belt(%d)", i);
		if not hasXMLProperty(xmlFile, key) then
            break;
        end;
      	local node = Utils.indexToObject(self.components, getXMLString(xmlFile, key.."#index"));
        local speed = Utils.getNoNil(getXMLFloat(xmlFile, key.."#speed"), 1);
			
		if node ~= nil then
            local rotPart = {};
            local j = 0;
            while true do
                local keyRotation = key..string.format(".rote(%d)", j);
				if not hasXMLProperty(xmlFile, keyRotation) then
                   break;
                end;
                local rotationNode = Utils.indexToObject(self.components, getXMLString(xmlFile, keyRotation.."#index"));
                local speedScale = Utils.getNoNil(getXMLFloat(xmlFile, keyRotation.."#speedScale"));
				local direction = Utils.getNoNil(getXMLFloat(xmlFile, keyRotation.."#direction"), 1);
				if speedScale == nil then
                    speedScale = 1.0/Utils.getNoNil(getXMLFloat(xmlFile, keyRotation.."#radius"), 1);
                end;
                if rotationNode ~= nil then
                   table.insert(rotPart, {node=rotationNode, speedScale=speedScale, direction=direction});
                end;
                j = j + 1;
            end;
			table.insert(self.belt, {node=node, speed=speed, sp=0, rotPart=rotPart});
		end;
		i = i +1;
	end;
	
	self.misc = {};
    local k = 0;			
	while true do
		local keyMisc = string.format("vehicle.rcw3.misc(%d)", k);
		if not hasXMLProperty(xmlFile, keyMisc) then
			break;
		end;
		local nodeMisc = Utils.indexToObject(self.components, getXMLString(xmlFile, keyMisc.."#index"));
		local speedMisc = Utils.getNoNil(getXMLFloat(xmlFile, keyMisc.."#speed"), 1);
		local axis = Utils.getNoNil(getXMLFloat(xmlFile, keyMisc.."#axis"), 1);
		if nodeMisc ~= nil then
            table.insert(self.misc, {nodeMisc=nodeMisc, speedMisc=speedMisc, axis=axis});
        end;
		k = k + 1;
	end;
end;

function rcw3000:delete()
end;

function rcw3000:mouseEvent(posX, posY, isDown, isUp, button)
end;

function rcw3000:keyEvent(unicode, sym, modifier, isDown)
end;

function rcw3000:update(dt)

	if self:getIsActive() then
		if self.isTurnedOn then
			for _, part in pairs(self.belt) do
				part.sp = part.sp + part.speed;
				setShaderParameter(part.node, "UVPlaySpeed", 0, part.sp*part.speed, 0, 0, false);
				
				for _, rotatingPart in pairs(part.rotPart) do
					local rotSpeed = dt*part.speed*rotatingPart.speedScale*rotatingPart.direction;
					rotate(rotatingPart.node, rotSpeed, 0, 0);
				end;
			end;
			
			for _, miscPart in pairs(self.misc) do
				if miscPart.axis == 1 then
					rotate(miscPart.nodeMisc, -dt*miscPart.speedMisc, 0, 0);
				elseif miscPart.axis == 2 then
					rotate(miscPart.nodeMisc, 0, -dt*miscPart.speedMisc, 0);
				elseif miscPart.axis == 3 then
					rotate(miscPart.nodeMisc, 0, 0, -dt*miscPart.speedMisc);
				end;
			end;
		else
			for _, part in pairs(self.belt) do
				setShaderParameter(part.node, "UVPlaySpeed", 0, 0, 0, 0, false);
			end;
		end;
	end;
end;

function rcw3000:onLeave()
end;

function rcw3000:onEnter()
end;

function rcw3000:draw()
end;
